@@ -7,13 +7,14 @@ from .kernels import (
     mala,
     nuts,
     orbital_hmc,
+    pathfinder_adaptation,
     rmh,
     sgld,
     tempered_smc,
     window_adaptation,
 )
 
-__version__ = "0.7.0"
+__version__ = "0.8.0"
 
 __all__ = [
     "hmc",  # mcmc
@@ -28,4 +29,5 @@ __all__ = [
     "tempered_smc",
     "ess",  # diagnostics
     "rhat",
+    "pathfinder_adaptation",
 ]
